/******************************************************************************
FILE:               O2CI8Environment.h
LANGUAGE:           Objective-C
SYSTEM:             None
USER-INTERFACE:     None
DESCRIPTION
    $Header$
    This is the definition of the O2CI8Environment class.
    The class O2CI8Environment manages the initialization of the OCI environment.
	It contains a singleton global instance.

AUTHORS
    <PJB>  Pascal J. Bourguignon  <pjb@imaginet.fr>
MODIFICATIONS
    $Log$
    1999/07/27 Creation.
BUGS
    - It's not implemented yet.
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#ifndef __O2CI8Environment_h__
#define __O2CI8Environment_h__
#include <O2CI8Object.h>


@interface O2CI8Environment:O2CI8Object
{
}

// NSObject methods:

	-(id)init;
		/*
			SEE:        +initializeWithMode:, and +instance.

			DO:         If an O2CI8Environment instance already exists, 
						then release this one and return the singleton,
						else [self initWithMode:OCI_DEFAULT].

			WARNING:    The designated initializer is initWithMode:.

			POST:       result==nil or the singleton is created.

			RETURN:     the singleton, 
						or nil if a problem occured with [super init].
		*/

    -(void)dealloc;


// O2CI8Environment methods:

	+(BOOL)initializeWithMode:(ub4)mode;
		/*
			DO:         Create the singleton instance using the mode.

			mode:       OCI_DEFAULT, 
						or an or-combinaison of OCI_THREADED and OCI_OBJECT.
						To be compatible with Oracle87, avoid OCI_OBJECT.
		
			SEE:        -initWithMode:.

			NOTE:       This class method has no relation to +initialize.
						In perticular, this one is not called automatically.

			RETURN:     the singleton is created.
		*/

	+(O2CI8Environment*)instance;
		/*
			RETURN:     The singleton instance. If it was not already created,
					    then it's created with +initializeWithMode:OCI_DEFAULT,
						or nil if a problem occured with [super init].
		*/


    -(id)initWithMode:(ub4)mode;
		/*
			SEE:        +initializeWithMode:, and +instance.

			NOTE:       This is the designated initializer. 

			DO:         If an O2CI8Environment instance already exists, 
						then release this one and return the singleton,
					    else call OCIInitialize().

			mode:       OCI_DEFAULT, 
						or an or-combinaison of OCI_THREADED and OCI_OBJECT.
						To be compatible with Oracle87, avoid OCI_OBJECT.

			RETURN:     the singleton, 
						or nil if a problem occured with [super init].
	*/



@end //O2CI8Environment;

#endif /*__O2CI8Environment_h__*/

/*** O2CI8Environment.h -- 1999/07/27 05:49:33 -- <PJB> ***/
