/******************************************************************************
FILE:               O2CI8Environment.m
LANGUAGE:           Objective-C
SYSTEM:             None
USER-INTERFACE:     None
DESCRIPTION
    $Header$
    This is the implementation of the O2CI8Environment class.
    The class O2CI8Environment manages the initialization of the OCI environment,
	and provide factories for the different OCI objects needed to access the
	Oracle8 databases.

AUTHORS
    <PJB>  Pascal J. Bourguignon  <pjb@imaginet.fr>
MODIFICATIONS
    $Log$
    1999/07/27 Creation.
BUGS
    - It's not implemented yet.
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#include <O2CI8Environment.h>
#include <Oracle8Utilities.h>

@implementation O2CI8Environment

    static const char*      rcsid="$Id";
	static O2CI8Environment*  singleton=nil;

// NSObject methods:

    -(id)init
    {
		if(singleton==nil){
			self=[self initWithMode:OCI_DEFAULT];
			singleton=self;
		}else{
			self=[super init]; // To be able to autorelease it.
			[self autorelease];
			self=singleton;
		}
		return(singleton);
	}//init;


    -(void)dealloc
    {
        // RELEASES.
        [super dealloc];
    }//dealloc;


// O2CI8Environment methods:

	+(BOOL)initializeWithMode:(ub4)mode
	{
		if(singleton==nil){
			singleton=[[self alloc] initWithMode:mode];
		}
		return(singleton!=nil);
	}//initializeWithMode:;

	
	+(O2CI8Environment*)instance
	{
		if(singleton==nil){
			[self initializeWithMode:OCI_DEFAULT];
		}
		return(singleton);
	}//instance;


    -(id)initWithMode:(ub4)mode
	{
		if(singleton==nil){
			self=[super init];
			if(self!=nil){
				if([self processErrorCode:OCIInitialize(mode,(dvoid*)0,
								(dvoid*(*)())0,(dvoid*(*)())0,(void(*)())0)
						 from:CURRENT_METHOD_AND(@"/OCIInitialize")
						 mayRaise:NO]){
					handleType=OCI_HTYPE_ENV;
					handleIsValid=[self processErrorCode:
							OCIEnvInit((OCIEnv**)&handle,OCI_DEFAULT,0,(dvoid**)0)
							/* other mode is   OCI_NO_MUTEX ! */
						from:CURRENT_METHOD_AND(@"/OCIEnvInit")
						mayRaise:NO];
				}
			}
			singleton=self;
		}else{
			self=[super init]; // To be able to autorelease it.
			[self autorelease];
			self=singleton;
		}
		return(singleton);
	}//initWithMode:;



@end //O2CI8Environment;

/*** O2CI8Environment.m -- 1999/07/27 05:49:34 -- <PJB> ***/

