/******************************************************************************
FILE:               O2CI8Parameter.h
LANGUAGE:           Objective-C
SYSTEM:             None
USER-INTERFACE:     None
DESCRIPTION
    $Header$
    This is the definition of the O2CI8Parameter class.
    The class O2CI8Parameter  encapsulate OCIParam parameter descriptions,
	that give information about fetched columns (and other meta-data about
	the database).

AUTHORS
    <PJB>  Pascal J. Bourguignon  <pjb@imaginet.fr>
MODIFICATIONS
    $Log$
    1999/08/02 Creation.
BUGS
    - 
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#ifndef __O2CI8Parameter_h__
#define __O2CI8Parameter_h__
#include <AppKit/AppKit.h>
#include <Foundation/Foundation.h>
#include <O2CI8Object.h>

@interface O2CI8Parameter:O2CI8Object
{
}

// NSObject methods:

    -(id)init;
		/*
			RAISE:      xxxx

			NOTE:       Clients should use +parameterWithHandle: to create
						instances of a subclass of O2CI8Parameter, since this
						is an "abstract" class.

			NOTE:       For subclasses, the designated initialized is:
							-(id)initWithHandle:(dvoid*)anHandle 
									type:(ub4)anHandleType;
		*/

    -(void)dealloc;


// O2CI8Object methods:

    -(id)initWithHandle:(dvoid*)anHandle type:(ub4)anHandleType;
		/*
			NOTE:       Clients should use +parameterWithHandle: to create
						parameter instances since this is an "abstract" class.
			
			IPRE:       anHandle must be an OCIParam* handle.
						anHandleType==OCI_DTYPE_PARAM.

			RETURN:     self, or nil when a problem occur with [super init].

		    POST:       self!=nil ==> [self handleIsValid].

			NOTE:       client must take care to provide a valid handle/type.

			NOTE:       subclasses may need more setup, in particular, they
						must allocate the error attribute if they need to
						report OCI errors.
		*/


// O2CI8Parameter methods:

	+(id)parameterWithHandle:(dvoid*)anHandle;
		/*
			PRE:        anHandle must be an OCIParam* handle.

			RETURN:     depending on the type of parameter handle given 
						(parameterType), returns an instance of one of 
						the subclasses of O2CI8Parameter, or nil if a 
						problem occurs.
		*/


	-(ub1)parameterType;
	-(BOOL)getTimeStamp:(ub1*)orats;
	-(ub2)numAttributes;
	-(ub2)numParameters;

	-(NSArray*)getParameters;


@end //O2CI8Parameter;

#endif /*__O2CI8Parameter_h__*/

/*** O2CI8Parameter.h -- 1999/08/02 00:32:35 -- <PJB> ***/
