/******************************************************************************
FILE:               O2CI8Parameter.m
LANGUAGE:           Objective-C
SYSTEM:             None
USER-INTERFACE:     None
DESCRIPTION
    $Header$
    This is the implementation of the O2CI8Parameter class.
    The class O2CI8Parameter is xxxxxx.
    The implementation of the class O2CI8Parameter xxxxxxx.

AUTHORS
    <PJB>  Pascal J. Bourguignon  <pjb@imaginet.fr>
MODIFICATIONS
    $Log$
    1999/08/02 Creation.
BUGS
    - 
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#include <O2CI8Parameter.h>
#include <O2CI8Table.h>
#include <O2CI8View.h>
#include <O2CI8Column.h>
#include <O2CI8List.h>
#include <O2CI8Error.h>
#include <Oracle8Utilities.h>



@interface O2CI8Parameter(Private)

	+(Class)getClassForParameterType:(ub1)ptype;

@end //O2CI8Parameter(Private);


// -------------------------------------------------------------------------- //

@implementation O2CI8Parameter

    static const char* rcsid="$Id";

// NSObject methods:

    -(id)init
    {
        self=[super init];
        if(self!=nil){
            // INITIALIZATIONS.
        }
        return(self);
    }//init;


    -(void)dealloc
    {
        handleIsValid=NO; // prevent deallocation of handle which is done
						  // anyway by its own OCI hierarchy.
        [super dealloc];
    }//dealloc;


// O2CI8Object methods:

	
    -(id)initWithHandle:(dvoid*)anHandle type:(ub4)anHandleType
	{
		if(anHandleType!=OCI_DTYPE_PARAM){
			[NSException raise:O2CI8Object_eInvalidParameter	format:@""];
		}
		self=[super initWithHandle:anHandle type:anHandleType];
		if(self!=nil){
			error=[[O2CI8Error alloc]init];
		}
		return(self);
	}//initWithHandle:type:;



// O2CI8Parameter methods:

	+(id)parameterWithHandle:(dvoid*)anHandle
	{
		O2CI8Parameter* parameter=[[[self alloc]
					initWithHandle:anHandle type:OCI_DTYPE_PARAM]autorelease];
		ub1 ptype=[parameter parameterType];
		Class subclass=[self getClassForParameterType:ptype];
		if(ptype==OCI_PTYPE_UNK){
			return(nil);
		}else if(subclass==self){
			return(parameter);
		}else{
			return([[[subclass alloc]
					initWithHandle:anHandle type:OCI_DTYPE_PARAM]autorelease]);
		}
	}//parameterWithHandle:;


	-(ub1)parameterType
	{
		ub1 ptype;
		if([self getUb1:&ptype attribute:OCI_ATTR_PTYPE from:CURRENT_METHOD]){
			return(ptype);
		}else{
			return(OCI_PTYPE_UNK);
		}
	}//parameterType;


	-(BOOL)getTimeStamp:(ub1*)orats
	{
		return([self getDVoidP:(dvoid**)orats attribute:OCI_ATTR_TIMESTAMP
					from:CURRENT_METHOD]);
	}//getTimeStamp:


	-(ub2)numAttributes
	{
		ub2 num;
		if([self getUb2:&num attribute:OCI_ATTR_NUM_ATTRS
				from:CURRENT_METHOD]){
			return(num);
		}else{
			return(0);
		}
	}//numAttributes;


	-(ub2)numParameters
	{
		ub2 num;
		if([self getUb2:&num attribute:OCI_ATTR_NUM_PARAMS
				from:CURRENT_METHOD]){
			return(num);
		}else{
			return(0);
		}
	}//numParameters;


	-(NSArray*)getParameters
	{
		NSMutableArray* result=[[[NSMutableArray alloc]
							initWithCapacity:[self numParameters]]autorelease];
		OCIParam*       parameterHandle;
		ub4             index=1;
		sword           ociResult;

		/*
			Well, the Oracle8 OCI Documentation says that OCIParamGet `may'
			return OCI_NO_DATA when no more parameter are to be found, and
			~effectively~, it may!

			Meaning, that it DOES NOT; it returns OCI_ERROR with a plain
			ORA-24334: no descriptor for this position  error message.

			Therefore, we won't process errors in this method.
		*/

		while(OCI_SUCCESS==(ociResult=OCIParamGet(handle,handleType,
							[error handle],(dvoid*)&parameterHandle,index))){
			//NSLog(@"OCIParamGet(#%d)-->%d\n",index,ociResult);
            [result addObject:
						[O2CI8Parameter parameterWithHandle:parameterHandle]];
			index++;
		}
		//NSLog(@"OCIParamGet(#%d)-->%d\n",index,ociResult);

		return(result);
		/* --
		if(ociResult==OCI_NO_DATA){
			return(result);
		}else{
			[self processErrorCode:ociResult 
					from:CURRENT_METHOD_AND(@"/OCIParamGet")];
			return(nil);
		}
		-- */
	}//getParameters;


@end //O2CI8Parameter;


// -------------------------------------------------------------------------- //

@implementation O2CI8Parameter(Private)


	+(Class)getClassForParameterType:(ub1)ptype
	{
		static Class subclasses[17];
		static BOOL  subclasses_initialized=NO;
		if(!subclasses_initialized){
			subclasses[OCI_PTYPE_UNK        ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_TABLE      ]=[O2CI8Table     class];
			subclasses[OCI_PTYPE_VIEW       ]=[O2CI8View      class];
			subclasses[OCI_PTYPE_PROC       ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_FUNC       ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_PKG        ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_TYPE       ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_SYN        ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_SEQ        ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_COL        ]=[O2CI8Column    class];
			subclasses[OCI_PTYPE_ARG        ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_LIST       ]=[O2CI8List      class];
			subclasses[OCI_PTYPE_TYPE_ATTR  ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_TYPE_COLL  ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_TYPE_METHOD]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_TYPE_ARG   ]=[O2CI8Parameter class];
			subclasses[OCI_PTYPE_TYPE_RESULT]=[O2CI8Parameter class];
		}
		if((ptype<=OCI_PTYPE_UNK)||(OCI_PTYPE_TYPE_RESULT<ptype)){
			return(subclasses[OCI_PTYPE_UNK]);			
		}else{
			return(subclasses[ptype]);
		}
	}//getClassForParameterType:;

@end //O2CI8Parameter(Private);

/*** O2CI8Parameter.m -- 1999/08/02 00:32:36 -- <PJB> ***/


