/******************************************************************************
FILE:               O2CI8ServiceContext.m
LANGUAGE:           Objective-C
SYSTEM:             None
USER-INTERFACE:     None
DESCRIPTION
    $Header$
    This is the implementation of the O2CI8ServiceContext class.
    The class O2CI8ServiceContext is xxxxxx.
    The implementation of the class O2CI8ServiceContext xxxxxxx.

AUTHORS
    <PJB>  Pascal J. Bourguignon  <pjb@imaginet.fr>
MODIFICATIONS
    $Log$
    1999/07/27 Creation.
BUGS
    - It's not implemented yet.
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#include <O2CI8ServiceContext.h>
#include <O2CI8Environment.h>
#include <O2CI8Error.h>
#include <Oracle8Utilities.h>


@implementation O2CI8ServiceContext

    static const char* rcsid="$Id";

// NSObject methods:

    -(id)init
    {
        self=[super init];
        if(self!=nil){
            handleType=OCI_HTYPE_SVCCTX;
            handleIsValid=[self processErrorCode:OCIHandleAlloc(
            	                    [[O2CI8Environment instance]handle],
									&handle,handleType,0,(dvoid*)0)
							from:CURRENT_METHOD_AND(@"/OCIHandleAlloc")
							mayRaise:NO];
			error=[[O2CI8Error alloc]init];
			serverConnection=nil;
			userSession=nil;
			transaction=nil;
			sessionIsActive=NO; // SEE: if there can be multiple session ?
        }
        return(self);
    }//init;


    -(void)dealloc
    {
		if(sessionIsActive){
			[self endSession];
		}
		[transaction release];
		[userSession release];
		[serverConnection release];
        [super dealloc];
    }//dealloc;


// O2CI8Object methods:


    
// O2CI8ServiceContext methods:



	-(BOOL)beginSessionWithServer:(O2CI8ServerConnection*)server
			forUser:(O2CI8UserSession*)user withAuthentificationModes:(ub4)mode
	{
		static NSString* location=nil;
		if(location==nil){
			location=CURRENT_METHOD;
		}

		if(sessionIsActive){
			[NSException raise:O2CI8Object_eInvalidState format:location];
		}
		if(!handleIsValid){
			[NSException raise:O2CI8Object_eInvalidHandle format:location];
		}
		
		[serverConnection autorelease];  serverConnection=[server retain];
		[userSession autorelease];       userSession=[user retain];

		if(![self setDVoidP:[server handle] attribute:OCI_ATTR_SERVER
				  from:location]){
			return(NO);
		}

		if(![self processErrorCode:
				OCISessionBegin(handle,[error handle],[user handle],
							OCI_CRED_RDBMS,mode)
				from:location]){
			return(NO);
		}

		sessionIsActive=[self setDVoidP:[user handle] attribute:OCI_ATTR_SESSION
						from:location];

		return(sessionIsActive);
	}//beginSessionWithServer:forUser:;


	-(void)endSession
	{
		static NSString* location=nil;
		if(location==nil){
			location=CURRENT_METHOD;
		}

		if(!sessionIsActive){
			[NSException raise:O2CI8Object_eInvalidState format:location];
		}

		/*
			Contrarily to what the Oracle8 OCI documentation says,
			we cannot pass 0 instead of [userSession handle].

			The transaction is automatically commited.
			All the handles may be reused.
		*/
		sessionIsActive=![self processErrorCode:
				OCISessionEnd(handle,[error handle],
								[userSession handle],OCI_DEFAULT)
			from:location];
	}//endSession;


	-(BOOL)sessionIsActive
	{
		return(sessionIsActive);
	}//sessionIsActive;


	-(O2CI8ServerConnection*)serverConnection
	{
		if(!handleIsValid){
			[NSException raise:O2CI8Object_eInvalidHandle format:CURRENT_METHOD];
		}
		return(serverConnection);
	}//serverConnection;


	-(O2CI8UserSession*)userSession;
	{
		if(!handleIsValid){
			[NSException raise:O2CI8Object_eInvalidHandle format:CURRENT_METHOD];
		}
		return(userSession);
	}//userSession;


	-(O2CI8Transaction*)transaction;
	{
		if(!handleIsValid){
			[NSException raise:O2CI8Object_eInvalidHandle format:CURRENT_METHOD];
		}
		return(transaction);
	}//transaction;


// Transaction management methods:

	/*
		I would have put transaction methods into O2CI8Transaction, but the
		OCI API does all transaction manipulations thru the service context.
	*/


	-(BOOL)transactionCommit:(ub4)flags
	{
		return([self processErrorCode:
			OCITransCommit(handle,[error handle],flags)
			from:CURRENT_METHOD_AND(@"/OCITransCommit")]);
	}//transactionCommit:;



	-(BOOL)transactionRollback
	{
		return([self processErrorCode:
			OCITransRollback(handle,[error handle],OCI_DEFAULT)
			from:CURRENT_METHOD_AND(@"/OCITransRollback")]);
	}//transactionRollback;


	-(BOOL)transactionStartBranchTimeout:(uword)timeout flags:(ub4)flags
	{
		return([self processErrorCode:
			OCITransStart(handle,[error handle],timeout,flags)
			from:CURRENT_METHOD_AND(@"/OCITransStart")]);
	}//transactionStartBranchTimeout:flags;


	-(BOOL)transactionDetach
	{
		return([self processErrorCode:
			OCITransDetach(handle,[error handle],OCI_DEFAULT)
			from:CURRENT_METHOD_AND(@"/OCITransDetach")]);
	}//transactionDetach;


	-(BOOL)transactionPrepare
	{
		return([self processErrorCode:
			OCITransPrepare(handle,[error handle],OCI_DEFAULT)
			from:CURRENT_METHOD_AND(@"/OCITransPrepare")]);
	}//transactionPrepare;


	-(BOOL)transactionForget
	{
		return([self processErrorCode:
			OCITransForget(handle,[error handle],OCI_DEFAULT)
			from:CURRENT_METHOD_AND(@"/OCITransForget")]);
	}//transactionForget;


// Statement execution methods:

	-(BOOL)executeStatement:(O2CI8Statement*)statement
			iterations:(ub4)nIter rowOffset:(ub4)rOffset 
			snapIn:(const OCISnapshot*)sIn snapOut:(OCISnapshot*)sOut
			mode:(ub4)mode
	{
		return([self processErrorCode:
			OCIStmtExecute(handle,[statement handle],[error handle],
				nIter,rOffset,(CONST OCISnapshot*)sIn,sOut,mode)
			from:CURRENT_METHOD_AND(@"/OCIStmtExecute")]);
	}//executeStatement:iterations:rowOffset:snapIn:snapOut:mode:;



@end //O2CI8ServiceContext;

/*** O2CI8ServiceContext.m -- 1999/07/27 06:35:56 -- <PJB> ***/

