/******************************************************************************
FILE:               O2CI8Statement.h
LANGUAGE:           Objective-C
SYSTEM:             None
USER-INTERFACE:     None
DESCRIPTION
    $Header$
    This is the definition of the O2CI8Statement class.
    The class O2CI8Statement is xxxxxx.

AUTHORS
    <PJB>  Pascal J. Bourguignon  <pjb@imaginet.fr>
MODIFICATIONS
    $Log$
    1999/07/27 Creation.
BUGS
    - It's not implemented yet.
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#ifndef __O2CI8Statement_h__
#define __O2CI8Statement_h__
#include <O2CI8Object.h>
#include <O2CI8Define.h>


@interface O2CI8Statement:O2CI8Object
{
}

// NSObject methods:

    -(id)init;
    -(void)dealloc;


// O2CI8Object methods:


    
// O2CI8Statement methods:

	-(BOOL)prepareStatement:(NSString*)sqlStatement inLanguage:(ub4)language;
		/*
			language:   OCI_V7_SYNTAX - V7 ORACLE parsing syntax 
			            OCI_V8_SYNTAX - V8 ORACLE parsing syntax 
                        OCI_NTV_SYNTAX - syntax depends upon the version 
                                         of the server.

			RETURN:     whether the statement has been prepared successfully.

			POST:       result==>[self statementType] return the type of statement.
						!result==>[self errorMessages] return the error messages.
		*/


	-(ub2)statementType;
		/*
			PRE:       the statement has been prepared successfully.
			RETURN:    the type of the statement, namely, one of:
							OCI_STMT_SELECT 
							OCI_STMT_UPDATE 
							OCI_STMT_DELETE 
							OCI_STMT_INSERT 
							OCI_STMT_CREATE 
							OCI_STMT_DROP 
							OCI_STMT_ALTER 
							OCI_STMT_BEGIN (PL/SQL statement) 
							OCI_STMT_DECLARE (PL/SQL statement) Attribute Datatype,
					   or 0 if an error occured.
		*/


	-(NSArray*)getParameters;
		/*
			PRE:        [self statementType]==OCI_STMT_SELECT

			RETURN:     an autoreleased array of O2CI8Parameter instances, 
						or nil if an error occured.
		*/


	-(O2CI8Define*)defineAtPosition:(ub4)position 
			buffer:(dvoid*)buffer bufferSize:(sb4)bufferSize dataType:(ub2)dataType
			indicator:(sb2*)indicator dataLength:(ub2*)dataLength
			returnCode:(ub2*)returnCode;
		/*
			PRE:        [self statementType]==OCI_STMT_SELECT

			DO:         Defines where to put data that will be obtained by 
						[self fetchRows:n].

			buffer:     either a pointer to the buffer, or a pointer to an
						array of pointers to the buffers, depending on whether
						multiple rows will be fetch at a time (in which case,
						you'll need to use also defineArrayOfStruct:...

			RETURN:     The define descriptor, or nil if an error occured.
		*/


	-(BOOL)fetchRows:(ub4)numRows;
		/*
			PRE:        [self statementType]==OCI_STMT_SELECT
			
			DO:         Fetches numRows rows into the defined fields.

			RETURN:     The number of rows actually fetched.
		*/
			

@end //O2CI8Statement;

#endif /*__O2CI8Statement_h__*/

/*** O2CI8Statement.h -- 1999/07/27 06:35:57 -- <PJB> ***/







