/******************************************************************************
FILE:               O2CI8Statement.m
LANGUAGE:           Objective-C
SYSTEM:             None
USER-INTERFACE:     None
DESCRIPTION
    $Header$
    This is the implemtation of the O2CI8Statement class.
    The class O2CI8Statement is xxxxxx.
    The implementation of the class O2CI8Statement xxxxxxx.

AUTHORS
    <PJB>  Pascal J. Bourguignon  <pjb@imaginet.fr>
MODIFICATIONS
    $Log$
    1999/07/27 Creation.
BUGS
    - It's not implemented yet.
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#include <O2CI8Statement.h>
#include <O2CI8Environment.h>
#include <O2CI8Error.h>
#include <O2CI8Parameter.h>
#include <Oracle8Utilities.h>


@implementation O2CI8Statement

    static const char* rcsid="$Id";

// NSObject methods:

    -(id)init
    {
        self=[super init];
        if(self!=nil){
            handleType=OCI_HTYPE_STMT;
            handleIsValid=[self processErrorCode:OCIHandleAlloc(
            	                    [[O2CI8Environment instance]handle],
									&handle,handleType,0,(dvoid*)0)
								from:CURRENT_METHOD_AND(@"/OCIHandleAlloc")
								mayRaise:NO];
			error=[[O2CI8Error alloc]init];
        }
        return(self);
    }//init;


    -(void)dealloc
    {
        // RELEASES.
        [super dealloc];
    }//dealloc;


// O2CI8Object methods:


    
// O2CI8Statement methods:


	-(BOOL)prepareStatement:(NSString*)sqlStatement inLanguage:(ub4)language
	{
		BOOL result;
		/* We have no garantee that the buffer won't be touched */
		text* buffer;
		ub4   length=[sqlStatement cStringLength];
		buffer=(text*)malloc(sizeof(text)*(length+1));
		[sqlStatement getCString:buffer maxLength:length];

		result=[self processErrorCode:
				OCIStmtPrepare(handle,[error handle],
						buffer,length,language,OCI_DEFAULT)
				from:CURRENT_METHOD_AND(@"/OCIStmtPrepare")];

		free(buffer);
		return(result);
	}//prepareStatement:inLanguage:;


	-(ub2)statementType
	{
		ub2 type=0;
		if([self getUb2:&type attribute:OCI_ATTR_STMT_TYPE 
				from:CURRENT_METHOD_AND(@"/OCIAttrGet")]){
			return(type);
		}else{
			return(0);
		}
	}//statementType;


	-(NSArray*)getParameters
	{
		NSMutableArray* result=[[[NSMutableArray alloc]
									initWithCapacity:8]autorelease];
		OCIParam*       parameterHandle;
		ub4             index=1;
		sword           ociResult;

		/*
			Well, the Oracle8 OCI Documentation says that OCIParamGet `may'
			return OCI_NO_DATA when no more parameter are to be found, and
			~effectively~, it may!

			Meaning, that it DOES NOT; it returns OCI_ERROR with a plain
			ORA-24334: no descriptor for this position  error message.

			Therefore, we won't process errors in this method.
		*/

		while(OCI_SUCCESS==(ociResult=OCIParamGet(handle,handleType,
							[error handle],(dvoid*)&parameterHandle,index))){
			//NSLog(@"OCIParamGet(#%d)-->%d\n",index,ociResult);
            [result addObject:
						[O2CI8Parameter parameterWithHandle:parameterHandle]];
			index++;
		}
		//NSLog(@"OCIParamGet(#%d)-->%d\n",index,ociResult);

		return(result);
		/* --
		if(ociResult==OCI_NO_DATA){
			return(result);
		}else{
			[self processErrorCode:ociResult 
					from:CURRENT_METHOD_AND(@"/OCIParamGet")];
			return(nil);
		}
		-- */
	}//getParameters;


	-(O2CI8Define*)defineAtPosition:(ub4)position 
			buffer:(dvoid*)buffer        bufferSize:(sb4)bufferSize
			dataType:(ub2)dataType       indicator:(sb2*)indicator
			dataLength:(ub2*)dataLength  returnCode:(ub2*)returnCode
	{
		OCIDefine*  defineHandle;
		sword ociResult=OCIDefineByPos(handle,&defineHandle,[error handle],
			position,buffer,bufferSize,dataType,indicator,dataLength,
			returnCode,OCI_DEFAULT);
NSLog(@"position=%2d dataType=%d bufferSize=%3d dataLength=%d\n",
position,dataType,bufferSize,*dataLength);

			/*
				No one  demo program  from Oracle8 pass  something else
				than  0 as  indicator, dataLength  and  returnCode. Do
				these  fields  really  work?   Actual  question:  what
				happens to the returnCode  (and other fields) when EOF
				occurs in the middle of fetching several rows?
			*/
		if([self processErrorCode:ociResult from:CURRENT_METHOD]){
			return([[[O2CI8Define alloc]initWithHandle:defineHandle 
					type:OCI_HTYPE_DEFINE]autorelease]);
		}else{
			return(nil);
		}
	}//defineAtPosition:buffer:bufferSize:dataType:indicator:dataLength:...;


	-(BOOL)fetchRows:(ub4)numRows
	{
		return([self processErrorCode:
				OCIStmtFetch(handle,[error handle],numRows,
					OCI_FETCH_NEXT,OCI_DEFAULT)
				from:CURRENT_METHOD]);
	}//fetchRows:;




@end //O2CI8Statement;

/*** O2CI8Statement.m -- 1999/07/27 06:35:57 -- <PJB> ***/

