/******************************************************************************
FILE:               Oracle8Adaptor.h
LANGUAGE:           Objective-C
SYSTEM:             GNUstep
USER-INTERFACE:     None
DESCRIPTION

    This class is the GNUstep/db adaptor to the Oracle8 databases.
	Its implementation is based on the OCI v8, and should be compatible
	with, both Oracle87, Oracle88 and future Oracle89 databases.
	
	The following keys are meaningful in the connectionDictionary in a model:

		userName       the name of the user (no default)
		password       the password used to connect to the server (no default)
		connectString  connection information.


AUTHORS
    <PJB> Pascal J. Bourguignon <pjb@imaginet.fr>
MODIFICATIONS
    1999/07/24 Creation.
BUGS
    - The name of this adaptor should probably be more specific.

LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999
	Copyright Software Builders     1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#ifndef __Oracle8Adaptor_h__
#define __Oracle8Adaptor_h__

#include <eoaccess/eoaccess.h>  // Let's leave  the  compiler  handle 
                                // intelligently pre-compiled headers!




// connectionDictionary keys:
extern NSString* Oracle8Adaptor_cdUsername;         // (@"username")
extern NSString* Oracle8Adaptor_cdPassword;         // (@"password")
extern NSString* Oracle8Adaptor_cdConnectionString; // (@"connectionString")

// exceptions:
extern NSString* Oracle8Adaptor_eBadInitializer;
extern NSString* Oracle8Adaptor_eInternalError;


@interface Oracle8Adaptor:EOAdaptor
{
    BOOL validatingConnectionDictionary; // very private attribute.
}


// NSObject methods:

	-(id)init;
	-(void)dealloc;


// EOAdaptor methods:

	-(id)initWithName:(NSString*)aName;
    -(void)setConnectionDictionary:(NSDictionary*)aDictionary;
	-(BOOL)hasValidConnectionDictionary;
	-(EOAdaptorContext*)createAdaptorContext;
	-(Class)expressionClass;
	-(Class)adaptorContextClass;
	-(Class)adaptorChannelClass;
	-(BOOL)isValidQualifierType:(NSString*)aTypeName;
	-(id)formatAttribute:(EOAttribute*)attribute;
	-(id)formatValue:(id)value forAttribute:(EOAttribute*)attribute;


// Oracle8Adaptor methods:

	// None. What would be the purpose of an EO adaptor layer if each and
	// every one EOAdaptor subclass  would add it's own specific methods?
	// Let the client use only the EOAdaptor API to access "portably" our
	// database.



@end // Oracle8Adaptor;


#endif /* __Oracle8Adaptor_h__ */
/*** Oracle8Adaptor.h -- 1999/07/24 04:44:47 -- PJB ***/
