/******************************************************************************
FILE:               Oracle8Buffer.h
LANGUAGE:           Objective-C
SYSTEM:             None
USER-INTERFACE:     None
DESCRIPTION
    $Header$
    This is the definition of the Oracle8Buffer class.

    The class Oracle8Buffer encapsulates an O2CI8Define and the buffer data
	passed to this define. It's able to convert data obtained from a fetch into
	OpenStep instances of NSNumber, NSString, NSDate, NSData.


AUTHORS
    <PJB>  Pascal J. Bourguignon  <pjb@imaginet.fr>
MODIFICATIONS
    $Log$
    1999/08/02 Creation.
BUGS
    - ...
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#ifndef __Oracle8Buffer_h__
#define __Oracle8Buffer_h__
#include <eoaccess/eoaccess.h>
#include <oci.h>

@class O2CI8Column;    // is a private class.
@class O2CI8Define;    // is a private class.
@class O2CI8Statement; // is a private class!


@interface Oracle8Buffer:NSObject
{
	O2CI8Column*         column; // source specification.
	O2CI8Define*         define; // just keeping it arround.
	void*               buffer;
	sb4                 bufferSize;
	ub2                 dataType;
	sb2                 indicator;
	ub2                 dataLength;
	ub2                 returnCode;
	EOAttribute*        attribute; // to know how to generate the value.
}

// NSObject methods:

    -(id)init;
    -(void)dealloc;


// Oracle8Buffer methods:
	
	-(BOOL)defineForColumn:(O2CI8Column*)aColumn 
			atPosition:(ub4)position
			inStatement:(O2CI8Statement*)aStatement
			asAttribute:(EOAttribute*)anAttribute;
		/*
			DO:         Set up the buffer for the column and define it in the
						statement.

			NOTE:       The current implementation only define the buffer for
						one row. Therefore only one row at a time can be fetched.

			RETURN:     Whether the buffer is successfully set up.

			POST:       result <=> self is not in mint condition.
		*/

	-(void)fillRow:(NSMutableDictionary*)row;

	-(NSData*)asData;
	-(NSNumber*)asNumber;
	-(NSString*)asString;
	-(NSDate*)asDate;
	-(NSCalendarDate*)asCalendarDate;

@end //Oracle8Buffer;

#endif /*__Oracle8Buffer_h__*/

/*** Oracle8Buffer.h -- 1999/08/02 20:31:46 -- <PJB> ***/
