/******************************************************************************
FILE:               Oracle8Channel.h
LANGUAGE:           Objective-C
SYSTEM:             GNUstep
USER-INTERFACE:     None
DESCRIPTION

    This class is the GNUstep/db channel to the Oracle8 databases.
	Its implementation is based on the OCI v8, and should be compatible
	with, both Oracle87, Oracle88 and future Oracle89 databases.

AUTHORS
    <PJB> Pascal J. Bourguignon <pjb@imaginet.fr>
MODIFICATIONS
    1999/07/24 Creation.
BUGS
    - ...
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999
	Copyright Software Builders     1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#ifndef __Oracle8Channel_h__
#define __Oracle8Channel_h__

#include <eoaccess/eoaccess.h>  // Let's leave  the  compiler  handle 
                                // intelligently pre-compiled headers!


@class O2CI8ServiceContext; // is a private class.
@class O2CI8Statement;      // is a private class.



//exceptions:
extern NSString* Oracle8Channel_eAttributeNotInResultSet;


@interface Oracle8Channel:EOAdaptorChannel
{
	O2CI8ServiceContext*  serviceContext;
	O2CI8Statement*       statement;
	unsigned long        oracleLanguage; // currently set to OCI_NTV_SYNTAX,
                                     // which means: SQL syntax of the server.
	NSMutableArray*      fetchResults;   // used for fetching.
	NSMutableArray*      fetchBuffers;   // used for fetching.
}


// NSObject methods:

	-(id)init;
		/*
			RAISE the bad initializer exception.
		*/

	-(void)dealloc;


// EOAdaptorChannel methods:

	-(id)initWithAdaptorContext:(EOAdaptorContext*)anAdaptorContext;
	-(BOOL)openChannel;
	-(NSArray*)describeResults;
	-(void)cancelFetch;
	-(NSMutableDictionary*)primaryFetchAttributes:(NSArray*)attributes 
			withZone:(NSZone*)zone;
	-(BOOL)evaluateExpression:(NSString*)anExpression;
	-(EOModel*)describeModelWithTableNames:(NSArray*)tableNames;
	-(NSArray*)describeTableNames;
	-(BOOL)readTypesForEntity:(EOEntity*)anEntity;
	-(BOOL)readTypeForAttribute:(EOAttribute*)anAttribute;



// Oracle8Channel methods:

	// None. What would be the purpose of an EO adaptor layer if each and every
	// one EOAdaptorChannel subclass would add it's own specific methods?
	// Let the client use only the EOAdaptorChannel API to access "portably" 
	// our database.


@end // Oracle8Channel;



#endif /* __Oracle8Channel_h__ */
/*** Oracle8Channel.h -- 1999/07/24 04:44:48 -- PJB ***/
