/******************************************************************************
FILE:               Oracle8Context-ForFriends.h
LANGUAGE:           Objective-C
SYSTEM:             GNUstep
USER-INTERFACE:     None
DESCRIPTION

	This category defines a private API of Oracle8Context 
	used by Oracle8Adaptor and Oracle8Channel.

	Its implementation is based on the OCI v8, and should be compatible
	with, both Oracle87, Oracle88 and future Oracle89 databases.

AUTHORS
    <PJB> Pascal J. Bourguignon <pjb@imaginet.fr>
MODIFICATIONS
    1999/07/25 Creation.
BUGS
    - ...
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999
	Copyright Software Builders     1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#ifndef __Oracle8Context_ForFriends_h__
#define __Oracle8Context_ForFriends_h__

@class O2CI8ServiceContext; // is a private class.

@interface Oracle8Context(ForFriends)
	
	/*
		Actually, the current implementation has one serviceContext 
		per Oracle8Context. This service context is shared amongst the
		Oracle8Channel instances of the same Oracle8Context.
		That's because the serviceContext manages the transaction.
	*/

	-(O2CI8ServiceContext*)createServiceContext;
		/*
			DO:         what it needs to do to connect to the database and
						begin a session with the connectionDictionary of
						the adaptor. If all went well, return its 
						O2CI8ServiceContext instance that can be used by the
						channel to access the database.

		    RETURN:     an newly connected O2CI8ServiceContext instance if
						successfull, nil otherwise.

			NOTE:       if the channel cannot complete successfully it's opening,
						it should send the context an disposeServiceContext:.

			NOTE:       if an error occur, it is reported automatically.
		*/


	-(void)disposeServiceContext:(O2CI8ServiceContext*)aServiceContext;
		/*
			NOTE:       the channel inform the context that it has finished
						with this service context.

		    DO:         end the session and dispose of the service context.
		*/


@end // Oracle8Context(ForFriends);


#endif /* __Oracle8Context_ForFriends_h__ */
/*** Oracle8Context-ForFriends.h -- 1999/07/24 04:44:49 -- PJB ***/
