/******************************************************************************
FILE:               Oracle8Context.h
LANGUAGE:           Objective-C
SYSTEM:             GNUstep
USER-INTERFACE:     None
DESCRIPTION

    This class is the GNUstep/db context to the Oracle8 databases.
	Its implementation is based on the OCI v8, and should be compatible
	with, both Oracle87, Oracle88 and future Oracle89 databases.

AUTHORS
    <PJB> Pascal J. Bourguignon <pjb@imaginet.fr>
MODIFICATIONS
    1999/07/24 Creation.
BUGS
    - ...
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999
	Copyright Software Builders     1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#ifndef __Oracle8Context_h__
#define __Oracle8Context_h__

#include <eoaccess/eoaccess.h>  // Let's leave  the  compiler  handle 
                                // intelligently pre-compiled headers!
#include <Oracle8Adaptor.h>
@class O2CI8ServiceContext; // is a private class.
@class O2CI8Transaction;    // is a private class.


@interface Oracle8Context:EOAdaptorContext
{
	O2CI8ServiceContext* serviceContext;
	O2CI8Transaction*    transaction;
	int                 numOpenChannels;
}

// NSObject methods:

	-(id)init;
		/*
			RAISE:      Oracle8Adaptor_eBadInitializer.
			SEE:        -[Oracle8Adaptor createAdaptorContext].
			SEE:        -[Oracle8Context initWithAdaptor:].
			NOTE:       The designated initializer is initWithAdaptor:.
		*/

	-(void)dealloc;


// EOAdaptorContext methods:

	-(id)initWithAdaptor:(EOAdaptor*)adaptor;

	-(EOAdaptorChannel*)createAdaptorChannel;
	-(BOOL)canNestTransactions;
	-(BOOL)primaryBeginTransaction;
	-(BOOL)primaryCommitTransaction;
	-(BOOL)primaryRollbackTransaction;


// Oracle8Context methods:

	// None. What would be the purpose of an EO adaptor layer if each and every
	// one EOAdaptorContext subclass would add it's own specific methods?
	// Let the client use only the EOAdaptorContext API to access "portably" 
	// our database.



@end // Oracle8Context;


#endif /* __Oracle8Context_h__ */
/*** Oracle8Context.h -- 1999/07/24 04:44:49 -- PJB ***/
