/******************************************************************************
FILE:               Oracle8Values.h
LANGUAGE:           Objective-C
SYSTEM:             GNUstep
USER-INTERFACE:     None
DESCRIPTION

    This module defines categories to several generic classes to convert
	Oracle8 values to instances of these classes.

AUTHORS
    <PJB> Pascal J. Bourguignon <pjb@imaginet.fr>
MODIFICATIONS
    1999/07/24 Creation.
BUGS
    - ...
LEGAL
    Copyright Pascal J. Bourguignon 1999 - 1999
	Copyright Software Builders     1999 - 1999

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
    License as published by the Free Software Foundation; either
    version 2 of the License, or (at your option) any later version.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Library General Public License for more details.

    You should have received a copy of the GNU Library General Public
    License along with this library; see the file COPYING.LIB.
    If not, write to the Free Software Foundation,
    59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
******************************************************************************/
#ifndef __Oracle8Values_h__
#define __Oracle8Values_h__

#include <eoaccess/eoaccess.h>  // Let's leave  the  compiler  handle 
                                // intelligently pre-compiled headers!
#include <Oracle8Channel.h>



@interface NSString(Oracle8ValueCreation)

	 +(id)valueFromBytes:(const char*)bytes
			length:(unsigned)lenth
			oracleType:(int)type
			attribute:(EOAttribute*)attribute
			adaptorChannel:(Oracle8Channel*)channel
			zone:(NSZone*)zone;

	-(NSString*)stringValueForOracle8Type:(int)type
			attribute:(EOAttribute*)attribute;

@end // NSString(Oracle8ValueCreation);



@interface NSNumber(Oracle8ValueCreation)

	+(id)valueFromBytes:(const char*)bytes
			length:(unsigned)lenth
			oracleType:(int)type
			attribute:(EOAttribute*)attribute
			adaptorChannel:(Oracle8Channel*)channel
			zone:(NSZone*)zone;


	-(NSString*)stringValueForOracle8Type:(int)type
			attribute:(EOAttribute*)attribute;

@end // NSNumber(Oracle8ValueCreation);



@interface NSData(Oracle8ValueCreation)

	+(id)valueFromBytes:(const char*)bytes
			length:(unsigned)lenth
			oracleType:(int)type
			attribute:(EOAttribute*)attribute
			adaptorChannel:(Oracle8Channel*)channel
			zone:(NSZone*)zone;

	-(NSString*)stringValueForOracle8Type:(int)type
			attribute:(EOAttribute*)attribute;

@end // NSData(Oracle8ValueCreation);



@interface NSCalendarDate(Oracle8ValueCreation)
	
	+(id)valueFromBytes:(const char*)bytes
			length:(unsigned)lenth
			oracleType:(int)type
			attribute:(EOAttribute*)attribute
			adaptorChannel:(Oracle8Channel*)channel
			zone:(NSZone*)zone;

	-(NSString*)stringValueForOracle8Type:(int)type
			attribute:(EOAttribute*)attribute;

@end // NSCalendarDate(Oracle8ValueCreation);



@interface EONull(Oracle8ValueCreation)

	-(NSString*)stringValueForOracle8Type:(int)type
			attribute:(EOAttribute*)attribute;

@end // EONull(Oracle8ValueCreation);



@interface NSObject(Oracle8ValueCreation)

	+(id)valueFromBytes:(const char*)bytes
			length:(unsigned)lenth
			oracleType:(int)type
			attribute:(EOAttribute*)attribute
			adaptorChannel:(Oracle8Channel*)channel
			zone:(NSZone*)zone;


	-(NSString*)stringValueForOracle8Type:(int)type
			attribute:(EOAttribute*)attribute;

@end // NSObject(Oracle8ValueCreation);



#endif /* __Oracle8Values_h__ */
/*** Oracle8Values.h -- 1999/07/24 04:44:50 -- PJB ***/
